@@ -90,7 +90,7 @@ class Agent:
 
 class Client:
 
-    def __init__(self, base_url: str = "https://api.subconscious.dev", api_key: str = None):
+    def __init__(self, base_url: str = "https://api.subconscious.dev/v1", api_key: str = None):
         openai_client = OpenAI(
             base_url=base_url, api_key=api_key
         )
