@@ -80,8 +80,8 @@ def tim_streaming(
     
     usage = Usage()
 
-    try:
-    # if True:
+    # try:
+    if True:
         # Make streaming request
         response = openai_client.chat.completions.create(
             model = model,
@@ -123,12 +123,12 @@ def tim_streaming(
             usage = usage
         )
         
-    except requests.exceptions.RequestException as e:
-        print(f"Request error: {e}")
-    except KeyboardInterrupt:
-        print("\nTest interrupted by user")
-    except Exception as e:
-        print(f"Unexpected error: {e}")
+    # except requests.exceptions.RequestException as e:
+    #     print(f"Request error: {e}")
+    # except KeyboardInterrupt:
+    #     print("\nTest interrupted by user")
+    # except Exception as e:
+    #     print(f"Unexpected error: {e}")
 
 def tim_streaming_legacy(model, messages, tools, reasoning_grammar_model):
     """Test the /v1/agent/parse endpoint with streaming enabled."""
